@@ -20,3 +20,5 @@ class TlmsWmsEntDirectListViewSet(YzModelViewSet):
     filter_backends = (DjangoFilterBackend, filters.SearchFilter, filters.OrderingFilter)
     filter_class = filter.TlmsWmsEntDirectFilter
     search_fields = ['contract_no', 'b_l_no']  # SearchFilter: like模糊搜索, query params为"search"，与search_fields来配合使用
+    ordering_fields = ['lastupdatedt']
+    ordering = ['-lastupdatedt']
