@@ -45,7 +45,7 @@ class Cargo(models.Model):
     hs_code = models.CharField(max_length=10, verbose_name="商品编码")
     ciq_code = models.CharField(max_length=10, verbose_name="商检编码", null=True, blank=True)
     name = models.CharField(max_length=100, verbose_name="货名", help_text="货名")
-    declare_elements = models.TextField(verbose_name="申报要素（商品规格型号、品牌）", help_text="申报要素（商品规格型号、品牌）")
+    declare_elements = models.TextField(verbose_name="申报要素（商品规格型号、品牌）", default='', help_text="申报要素（商品规格型号、品牌）")
     source_area = models.CharField(max_length=50, default='', verbose_name="原产地（国）", help_text="原产地（国）")
     source_area_name = models.CharField(max_length=50, default='', verbose_name="原产地（国）名称", help_text="原产地（国）名称", null=True, blank=True)
     natcd = models.CharField(max_length=10, verbose_name="国别", help_text="国别", null=True, blank=True)
@@ -64,10 +64,10 @@ class Cargo(models.Model):
     weight = models.DecimalField(verbose_name="重量/单位", null=True, blank=True, max_digits=10, decimal_places=4)
     volume = models.DecimalField(verbose_name="体积/单位", null=True, blank=True, max_digits=10, decimal_places=5)
     # tlms
-    specs_quantity = models.DecimalField(max_digits=10, default=0, decimal_places=2, verbose_name="规格量", help_text="规格量")
-    specs_unit = models.CharField(max_length=100, default='', verbose_name="规格单位", help_text="规格单位")
-    pack_quantity = models.DecimalField(max_digits=10, default=0, decimal_places=0, verbose_name="包装量", help_text="包装量")
-    pack_unit = models.CharField(max_length=100, default='', verbose_name="包装单位", help_text="包装单位")
+    specs_quantity = models.DecimalField(max_digits=10, default=0, null=True, blank=True, decimal_places=2, verbose_name="规格量", help_text="规格量")
+    specs_unit = models.CharField(max_length=100, default='', null=True, blank=True, verbose_name="规格单位", help_text="规格单位")
+    pack_quantity = models.DecimalField(max_digits=10, default=0, null=True, blank=True, decimal_places=0, verbose_name="包装量", help_text="包装量")
+    pack_unit = models.CharField(max_length=100, default='', null=True, blank=True, verbose_name="包装单位", help_text="包装单位")
 
     brand = models.CharField(max_length=50, null=True, blank=True, verbose_name="品牌", help_text="品牌")
     name_en = models.CharField(max_length=100, verbose_name="货物英文名", help_text="货物英文名", null=True, blank=True)
